@@ -121,7 +121,7 @@ class Experiment:
             print("Running...")
         print_status(self)
 
-    def plot(self, tubes=None, window_size=30, close=True):
+    def plot(self, tubes=None, window_size=30, close=True, dpi=150):
         if tubes is None:
             tubes = self.active_tubes
         if len(tubes) == 0:
@@ -129,7 +129,7 @@ class Experiment:
         log_OD = pd.read_csv(self.OD_measurement.od_file, parse_dates=["time"], index_col="time")
         log_pumps = pd.read_csv(os.path.join(self.name, "log_pumps.csv"), parse_dates=["time"], index_col="time")
         for tube in tubes:
-            plot_tube(self, tube, log_OD=log_OD, log_pumps=log_pumps, window_size=window_size,close=close)
+            plot_tube(self, tube, log_OD=log_OD, log_pumps=log_pumps, window_size=window_size, close=close, dpi=dpi)
 
     def stop_experiment(self):
         with open(os.path.join(self.name, "stop.experiment"), "w+"):
