@@ -71,7 +71,7 @@ def _read_parameters_OD_thresholds(pe):
     return OD_thresholds
 
 
-def dilute_if_necessary(pe, total_dilution_volume=10):
+def dilute_if_necessary(pe, total_dilution_volume=10,delta_t_min=900):
     OD_thresholds = pe.parameters_OD_thresholds
     drug_doses = pe.parameters_drug_doses
 
@@ -80,11 +80,18 @@ def dilute_if_necessary(pe, total_dilution_volume=10):
     for tube in range(7):
         if OD_thresholds[tube] > 0.15 and tube in pe.active_tubes:
             if pe.last_OD_values[tube] > OD_thresholds[tube]:
-                make_dilution(pe, tube,
+                if time_since_last_pump(pe,tube)>delta_t_min:
+                    make_dilution(pe, tube,
                               death_volume=death_volumes[tube],
                               peace_volume=peace_volumes[tube],
                               extra_vacuum=5)
 
+def time_since_last_pump(pe,t):
+    df = pd.read_csv(os.path.join(pe.name, "log_pumps.csv"))
+    timenow=pd.Timestamp(time.ctime())
+    timedeltas=timenow-df.groupby("tube")["time"].max().apply(pd.Timestamp)
+    timedeltas=timedeltas.apply(lambda x: x.total_seconds())
+    return timedeltas[t]
 
 def pause_mixers_and_measure_OD(pe):
     pe.mix(pe.mixer_speed)
